@@ -19,14 +19,13 @@
  */
 
 #include "app.h"
-#include "gtkaccelparse_p.h"
 #include "gdkkeysyms_p.h"
-#include <QTimer>
-#include <QDebug>
-#include <QX11Info>
-#include <QDBusServiceWatcher>
+#include "gtkaccelparse_p.h"
 #include <QDBusConnection>
-#include <xcb/xcb_keysyms.h>
+#include <QDBusServiceWatcher>
+#include <QDebug>
+#include <QTimer>
+#include <QX11Info>
 
 #define USED_MASK (XCB_MOD_MASK_SHIFT | XCB_MOD_MASK_CONTROL | XCB_MOD_MASK_1 | XCB_MOD_MASK_4)
 
@@ -37,17 +36,17 @@ bool XcbEventFilter::nativeEventFilter(const QByteArray &eventType, void *messag
         return false;
     }
 
-    return qobject_cast<App*>(qApp)->nativeEvent(static_cast<xcb_generic_event_t*>(message));
+    return qobject_cast<App *>(qApp)->nativeEvent(static_cast<xcb_generic_event_t *>(message));
 }
 
 // callback functions from glib code
-static void name_acquired_cb (GDBusConnection* connection,
-                              const gchar* sender_name,
-                              const gchar* object_path,
-                              const gchar* interface_name,
-                              const gchar* signal_name,
-                              GVariant* parameters,
-                              gpointer self)
+static void name_acquired_cb(GDBusConnection *connection,
+                             const gchar *sender_name,
+                             const gchar *object_path,
+                             const gchar *interface_name,
+                             const gchar *signal_name,
+                             GVariant *parameters,
+                             gpointer self)
 {
     Q_UNUSED(connection);
     Q_UNUSED(sender_name);
@@ -55,17 +54,17 @@ static void name_acquired_cb (GDBusConnection* connection,
     Q_UNUSED(interface_name);
     Q_UNUSED(signal_name);
     Q_UNUSED(parameters);
-    App* app = (App*) self;
+    App *app = (App *)self;
     app->nameAcquired();
 }
 
-static void name_lost_cb (GDBusConnection* connection,
-                          const gchar* sender_name,
-                          const gchar* object_path,
-                          const gchar* interface_name,
-                          const gchar* signal_name,
-                          GVariant* parameters,
-                          gpointer self)
+static void name_lost_cb(GDBusConnection *connection,
+                         const gchar *sender_name,
+                         const gchar *object_path,
+                         const gchar *interface_name,
+                         const gchar *signal_name,
+                         GVariant *parameters,
+                         gpointer self)
 {
     Q_UNUSED(connection);
     Q_UNUSED(sender_name);
@@ -73,29 +72,25 @@ static void name_lost_cb (GDBusConnection* connection,
     Q_UNUSED(interface_name);
     Q_UNUSED(signal_name);
     Q_UNUSED(parameters);
-    App* app = (App*) self;
+    App *app = (App *)self;
     app->nameLost();
 }
 
-static void
-ibus_connected_cb (IBusBus  *m_bus,
-                   gpointer  user_data)
+static void ibus_connected_cb(IBusBus *m_bus, gpointer user_data)
 {
     Q_UNUSED(m_bus);
-    App* app = (App*) user_data;
+    App *app = (App *)user_data;
     app->init();
 }
 
-static void
-ibus_disconnected_cb (IBusBus  *m_bus,
-                      gpointer  user_data)
+static void ibus_disconnected_cb(IBusBus *m_bus, gpointer user_data)
 {
     Q_UNUSED(m_bus);
-    App* app = (App*) user_data;
+    App *app = (App *)user_data;
     app->finalize();
 }
 
-static void initIconMap(QMap<QByteArray, QByteArray>& iconMap)
+static void initIconMap(QMap<QByteArray, QByteArray> &iconMap)
 {
     iconMap["gtk-about"] = "help-about";
     iconMap["gtk-add"] = "list-add";
@@ -178,15 +173,16 @@ static void initIconMap(QMap<QByteArray, QByteArray>& iconMap)
     iconMap["gtk-zoom-out"] = "zoom-out";
 }
 
-App::App(int &argc, char* argv[]): QGuiApplication(argc, argv)
-    ,m_eventFilter(new XcbEventFilter)
-    ,m_init(false)
-    ,m_bus(ibus_bus_new ())
-    ,m_impanel(nullptr)
-    ,m_keyboardGrabbed(false)
-    ,m_doGrab(false)
-    ,m_syms(nullptr)
-    ,m_watcher(new QDBusServiceWatcher(this))
+App::App(int &argc, char *argv[])
+    : QGuiApplication(argc, argv)
+    , m_eventFilter(new XcbEventFilter)
+    , m_init(false)
+    , m_bus(ibus_bus_new())
+    , m_impanel(nullptr)
+    , m_keyboardGrabbed(false)
+    , m_doGrab(false)
+    , m_syms(nullptr)
+    , m_watcher(new QDBusServiceWatcher(this))
 {
     m_syms = xcb_key_symbols_alloc(QX11Info::connection());
     installNativeEventFilter(m_eventFilter.data());
@@ -199,16 +195,7 @@ App::App(int &argc, char* argv[]): QGuiApplication(argc, argv)
 
 uint App::getPrimaryModifier(uint state)
 {
-    const GdkModifierType masks[] = {
-        GDK_MOD5_MASK,
-        GDK_MOD4_MASK,
-        GDK_MOD3_MASK,
-        GDK_MOD2_MASK,
-        GDK_MOD1_MASK,
-        GDK_CONTROL_MASK,
-        GDK_LOCK_MASK,
-        GDK_LOCK_MASK
-    };
+    const GdkModifierType masks[] = {GDK_MOD5_MASK, GDK_MOD4_MASK, GDK_MOD3_MASK, GDK_MOD2_MASK, GDK_MOD1_MASK, GDK_CONTROL_MASK, GDK_LOCK_MASK, GDK_LOCK_MASK};
     for (size_t i = 0; i < sizeof(masks) / sizeof(masks[0]); i++) {
         GdkModifierType mask = masks[i];
         if ((state & mask) == mask)
@@ -217,16 +204,16 @@ uint App::getPrimaryModifier(uint state)
     return 0;
 }
 
-bool App::nativeEvent(xcb_generic_event_t* event)
+bool App::nativeEvent(xcb_generic_event_t *event)
 {
     if ((event->response_type & ~0x80) == XCB_KEY_PRESS) {
-        auto keypress = reinterpret_cast<xcb_key_press_event_t*>(event);
+        auto keypress = reinterpret_cast<xcb_key_press_event_t *>(event);
         if (keypress->event == QX11Info::appRootWindow()) {
             auto sym = xcb_key_press_lookup_keysym(m_syms, keypress, 0);
             uint state = keypress->state & USED_MASK;
             bool forward;
             if ((forward = m_triggersList.contains(qMakePair<uint, uint>(sym, state)))
-             || m_triggersList.contains(qMakePair<uint, uint>(sym, state & (~XCB_MOD_MASK_SHIFT)))) {
+                || m_triggersList.contains(qMakePair<uint, uint>(sym, state & (~XCB_MOD_MASK_SHIFT)))) {
                 if (m_keyboardGrabbed) {
                     ibus_panel_impanel_navigate(m_impanel, false, forward);
                 } else {
@@ -239,7 +226,7 @@ bool App::nativeEvent(xcb_generic_event_t* event)
             }
         }
     } else if ((event->response_type & ~0x80) == XCB_KEY_RELEASE) {
-        auto keyrelease = reinterpret_cast<xcb_key_release_event_t*>(event);
+        auto keyrelease = reinterpret_cast<xcb_key_release_event_t *>(event);
         if (keyrelease->event == QX11Info::appRootWindow()) {
             keyRelease(keyrelease);
         }
@@ -247,7 +234,7 @@ bool App::nativeEvent(xcb_generic_event_t* event)
     return false;
 }
 
-void App::keyRelease(const xcb_key_release_event_t* event)
+void App::keyRelease(const xcb_key_release_event_t *event)
 {
     unsigned int mk = event->state & USED_MASK;
     // ev.state is state before the key release, so just checking mk being 0 isn't enough
@@ -255,9 +242,7 @@ void App::keyRelease(const xcb_key_release_event_t* event)
     // modifiers are released: only one modifier is active and the currently released
     // key is this modifier - if yes, release the grab
     int mod_index = -1;
-    for (int i = XCB_MAP_INDEX_SHIFT;
-             i <= XCB_MAP_INDEX_5;
-             ++i)
+    for (int i = XCB_MAP_INDEX_SHIFT; i <= XCB_MAP_INDEX_5; ++i)
         if ((mk & (1 << i)) != 0) {
             if (mod_index >= 0)
                 return;
@@ -272,8 +257,7 @@ void App::keyRelease(const xcb_key_release_event_t* event)
         if (reply) {
             auto keycodes = xcb_get_modifier_mapping_keycodes(reply);
             for (int i = 0; i < reply->keycodes_per_modifier; i++) {
-                if (keycodes[reply->keycodes_per_modifier * mod_index + i]
-                        == event->detail) {
+                if (keycodes[reply->keycodes_per_modifier * mod_index + i] == event->detail) {
                     release = true;
                 }
             }
@@ -288,37 +272,42 @@ void App::keyRelease(const xcb_key_release_event_t* event)
     }
 }
 
-
 void App::init()
 {
     // only init once
     if (m_init) {
         return;
     }
-    if (!ibus_bus_is_connected (m_bus)) {
+    if (!ibus_bus_is_connected(m_bus)) {
         return;
     }
-    g_signal_connect (m_bus, "connected", G_CALLBACK (ibus_connected_cb), this);
-    g_signal_connect (m_bus, "disconnected", G_CALLBACK (ibus_disconnected_cb), this);
+    g_signal_connect(m_bus, "connected", G_CALLBACK(ibus_connected_cb), this);
+    g_signal_connect(m_bus, "disconnected", G_CALLBACK(ibus_disconnected_cb), this);
     connect(m_watcher, &QDBusServiceWatcher::serviceUnregistered, this, &App::finalize);
-    GDBusConnection* connection = ibus_bus_get_connection (m_bus);
-    g_dbus_connection_signal_subscribe (connection,
-                                        "org.freedesktop.DBus",
-                                        "org.freedesktop.DBus",
-                                        "NameAcquired",
-                                        "/org/freedesktop/DBus",
-                                        IBUS_SERVICE_PANEL, G_DBUS_SIGNAL_FLAGS_NONE,
-                                        name_acquired_cb, this, nullptr);
+    GDBusConnection *connection = ibus_bus_get_connection(m_bus);
+    g_dbus_connection_signal_subscribe(connection,
+                                       "org.freedesktop.DBus",
+                                       "org.freedesktop.DBus",
+                                       "NameAcquired",
+                                       "/org/freedesktop/DBus",
+                                       IBUS_SERVICE_PANEL,
+                                       G_DBUS_SIGNAL_FLAGS_NONE,
+                                       name_acquired_cb,
+                                       this,
+                                       nullptr);
 
-    g_dbus_connection_signal_subscribe (connection,
-                                        "org.freedesktop.DBus",
-                                        "org.freedesktop.DBus",
-                                        "NameLost",
-                                        "/org/freedesktop/DBus",
-                                        IBUS_SERVICE_PANEL, G_DBUS_SIGNAL_FLAGS_NONE,
-                                        name_lost_cb, this, nullptr);
+    g_dbus_connection_signal_subscribe(connection,
+                                       "org.freedesktop.DBus",
+                                       "org.freedesktop.DBus",
+                                       "NameLost",
+                                       "/org/freedesktop/DBus",
+                                       IBUS_SERVICE_PANEL,
+                                       G_DBUS_SIGNAL_FLAGS_NONE,
+                                       name_lost_cb,
+                                       this,
+                                       nullptr);
 
-    ibus_bus_request_name (m_bus, IBUS_SERVICE_PANEL, IBUS_BUS_NAME_FLAG_ALLOW_REPLACEMENT | IBUS_BUS_NAME_FLAG_REPLACE_EXISTING);
+    ibus_bus_request_name(m_bus, IBUS_SERVICE_PANEL, IBUS_BUS_NAME_FLAG_ALLOW_REPLACEMENT | IBUS_BUS_NAME_FLAG_REPLACE_EXISTING);
     m_init = true;
 }
 
@@ -327,7 +316,7 @@ void App::nameAcquired()
     if (m_impanel) {
         g_object_unref(m_impanel);
     }
-    m_impanel = ibus_panel_impanel_new (ibus_bus_get_connection (m_bus));
+    m_impanel = ibus_panel_impanel_new(ibus_bus_get_connection(m_bus));
     ibus_panel_impanel_set_bus(m_impanel, m_bus);
     ibus_panel_impanel_set_app(m_impanel, this);
 }
@@ -341,7 +330,7 @@ void App::nameLost()
     m_impanel = nullptr;
 }
 
-QByteArray App::normalizeIconName(const QByteArray& icon) const
+QByteArray App::normalizeIconName(const QByteArray &icon) const
 {
     if (m_iconMap.contains(icon)) {
         return m_iconMap[icon];
@@ -350,7 +339,7 @@ QByteArray App::normalizeIconName(const QByteArray& icon) const
     return icon;
 }
 
-void App::setTriggerKeys(QList< TriggerKey > triggersList)
+void App::setTriggerKeys(QList<TriggerKey> triggersList)
 {
     if (m_doGrab) {
         ungrabKey();
@@ -364,7 +353,8 @@ void App::setTriggerKeys(QList< TriggerKey > triggersList)
 
 void App::setDoGrab(bool doGrab)
 {
-    if (m_doGrab != doGrab) {;
+    if (m_doGrab != doGrab) {
+        ;
         if (doGrab) {
             grabKey();
         } else {
@@ -376,18 +366,22 @@ void App::setDoGrab(bool doGrab)
 
 void App::grabKey()
 {
-    Q_FOREACH(const TriggerKey& key, m_triggersList) {
+    Q_FOREACH (const TriggerKey &key, m_triggersList) {
         xcb_keysym_t sym = key.first;
         uint modifiers = key.second;
-        xcb_keycode_t* keycode = xcb_key_symbols_get_keycode(m_syms, sym);
+        xcb_keycode_t *keycode = xcb_key_symbols_get_keycode(m_syms, sym);
         if (!keycode) {
-            g_warning ("Can not convert keyval=%u to keycode!", sym);
+            g_warning("Can not convert keyval=%u to keycode!", sym);
         } else {
-            xcb_grab_key(QX11Info::connection(), true, QX11Info::appRootWindow(),
-                         modifiers, keycode[0], XCB_GRAB_MODE_ASYNC, XCB_GRAB_MODE_ASYNC);
+            xcb_grab_key(QX11Info::connection(), true, QX11Info::appRootWindow(), modifiers, keycode[0], XCB_GRAB_MODE_ASYNC, XCB_GRAB_MODE_ASYNC);
             if ((modifiers & XCB_MOD_MASK_SHIFT) == 0) {
-                xcb_grab_key(QX11Info::connection(), true, QX11Info::appRootWindow(),
-                             modifiers | XCB_MOD_MASK_SHIFT, keycode[0], XCB_GRAB_MODE_ASYNC, XCB_GRAB_MODE_ASYNC);
+                xcb_grab_key(QX11Info::connection(),
+                             true,
+                             QX11Info::appRootWindow(),
+                             modifiers | XCB_MOD_MASK_SHIFT,
+                             keycode[0],
+                             XCB_GRAB_MODE_ASYNC,
+                             XCB_GRAB_MODE_ASYNC);
             }
         }
         free(keycode);
@@ -396,12 +390,12 @@ void App::grabKey()
 
 void App::ungrabKey()
 {
-    Q_FOREACH(const TriggerKey& key, m_triggersList) {
+    Q_FOREACH (const TriggerKey &key, m_triggersList) {
         xcb_keysym_t sym = key.first;
         uint modifiers = key.second;
-        xcb_keycode_t* keycode = xcb_key_symbols_get_keycode(m_syms, sym);
+        xcb_keycode_t *keycode = xcb_key_symbols_get_keycode(m_syms, sym);
         if (!keycode) {
-            g_warning ("Can not convert keyval=%u to keycode!", sym);
+            g_warning("Can not convert keyval=%u to keycode!", sym);
         } else {
             xcb_ungrab_key(QX11Info::connection(), keycode[0], QX11Info::appRootWindow(), modifiers);
             if ((modifiers & XCB_MOD_MASK_SHIFT) == 0) {
@@ -412,12 +406,12 @@ void App::ungrabKey()
     }
 }
 
-bool App::grabXKeyboard() {
+bool App::grabXKeyboard()
+{
     if (m_keyboardGrabbed)
         return false;
     auto w = QX11Info::appRootWindow();
-    auto cookie = xcb_grab_keyboard(QX11Info::connection(), false, w, XCB_CURRENT_TIME,
-                                    XCB_GRAB_MODE_ASYNC, XCB_GRAB_MODE_ASYNC);
+    auto cookie = xcb_grab_keyboard(QX11Info::connection(), false, w, XCB_CURRENT_TIME, XCB_GRAB_MODE_ASYNC, XCB_GRAB_MODE_ASYNC);
     auto reply = xcb_grab_keyboard_reply(QX11Info::connection(), cookie, nullptr);
 
     if (reply && reply->status == XCB_GRAB_STATUS_SUCCESS) {
@@ -460,8 +454,8 @@ void App::clean()
     }
 
     if (m_bus) {
-        g_signal_handlers_disconnect_by_func(m_bus, (gpointer) ibus_disconnected_cb, this);
-        g_signal_handlers_disconnect_by_func(m_bus, (gpointer) ibus_connected_cb, this);
+        g_signal_handlers_disconnect_by_func(m_bus, (gpointer)ibus_disconnected_cb, this);
+        g_signal_handlers_disconnect_by_func(m_bus, (gpointer)ibus_connected_cb, this);
         g_object_unref(m_bus);
         m_bus = nullptr;
     }
