@@ -35,7 +35,10 @@ public:
 
     void kcmInit() override;
 
-    bool isValid() const override { return m_dpy != nullptr; }
+    bool isValid() const override
+    {
+        return m_dpy != nullptr;
+    }
 
     QString currentCursorTheme();
     void applyCursorTheme(const QString &name, int size);
@@ -44,7 +47,7 @@ protected:
     X11Backend(QObject *parent = nullptr);
 
     // We may still need to do something on non-X11 platform due to Xwayland.
-    Display* m_dpy = nullptr;
+    Display *m_dpy = nullptr;
     bool m_platformX11;
 };
 
