@@ -30,7 +30,13 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("knetattach5");
 
-    KAboutData aboutData(QLatin1String("knetattach"), i18n("KDE Network Wizard"), QLatin1String(PROJECT_VERSION), i18n("KDE Network Wizard"),KAboutLicense::GPL, i18n("(c) 2004 George Staikos"), QLatin1String("https://www.kde.org/"));
+    KAboutData aboutData(QLatin1String("knetattach"),
+                         i18n("KDE Network Wizard"),
+                         QLatin1String(PROJECT_VERSION),
+                         i18n("KDE Network Wizard"),
+                         KAboutLicense::GPL,
+                         i18n("(c) 2004 George Staikos"),
+                         QLatin1String("https://www.kde.org/"));
 
     aboutData.addAuthor(i18n("George Staikos"), i18n("Primary author and maintainer"), QStringLiteral("staikos@kde.org"));
 
@@ -39,9 +45,9 @@ int main(int argc, char **argv)
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
-	KNetAttach na;
-    app.connect( &app, &QGuiApplication::lastWindowClosed, &app, &QCoreApplication::quit );
-	na.show();
+    KNetAttach na;
+    app.connect(&app, &QGuiApplication::lastWindowClosed, &app, &QCoreApplication::quit);
+    na.show();
 
-	return app.exec();
+    return app.exec();
 }
